module.exports = defineTest({
	description: 'make sure removed statements do no leave unwanted white-space'
});
